@@ -25,7 +25,7 @@ There are several units that are specifically designed to store meta variables:
 
 There are a number of ways in which meta variables can be used. The most straightforward way is to
 use the `refinery.lib.argformats.DelayedArgument.var` handler to read the contents of a variable
-and use it as part of a multibin expression. The `refinery.lib.argformats.DelayedArgument.xvar`
+and use it as part of a multibin expression. The `refinery.lib.argformats.DelayedArgument.eat`
 handler works in the same way, except that the variable is removed from the meta dictionary after
 it has been used. Example:
 
@@ -61,6 +61,30 @@ least 200 from the input to incrementally numbered files:
 
     emit sample | carve --min=200 b64 [| dump buffer{index}.b64 ]
 
+### Magic Meta Variables
+
+As alluded to in the previous section, there are several meta variables that are available on every
+chunk, such as `size`, `entropy`, and `md5`. These values are computed as soon as they are accessed.
+Some of them are formatted differently when using the `r`-transformation; for example, the `size`
+variable will be printed as a human-readable expression when formatted as `{size!r}`, but it will be
+a decimal string when formatted as `{size}` or `{size!s}`.
+
+- `index`: The index of the chunk in the current frame (see `refinery.lib.frame`).
+- `magic`: Human-readable file magic string.
+- `mime`: MIME type of the chunk according to file magic information.
+- `ext`: A guessed file extension based on file magic information.
+- `size`: The number of bytes in this chunk of data. The default formatting of this value is a
+   decimal integer, but its r-format is a human-readable size expression.
+- `entropy`: Information entropy value of the data. Its computation can be expensive for large
+   chunks. The r-format of this value is a percentage.
+- `ic`: The index of coincidence of the data. Its computation can be expensive for large chunks.
+   The r-format of this value is a percentage.
+- `crc32`: The hexadecimal representation of the CRC32-hash of the data.
+- `sha1`: The hexadecimal representation of the SHA1-hash of the data.
+- `sha256`: The hexadecimal representation of the SHA256-hash of the data.
+- `sha512`: The hexadecimal representation of the SHA512-hash of the data.
+- `md5`: The hexadecimal representation of the MD5-hash of the data.
+
 ### Using Push And Pop
 
 The `refinery.push` and `refinery.pop` units can be used to extract sub-pipelines as variables. For
@@ -189,14 +213,20 @@ class ByteStringWrapper(bytearray, CustomStringRepresentation):
             representation = None
         else:
             import re
-            if not re.fullmatch(r'[\s!-~]+', representation):
+            if not re.fullmatch(r'[\x20!-~]+', representation):
                 representation = None
             else:
                 prefix = self._CODECS[self.codec]
                 if prefix != 's' or self.requires_prefix():
                     representation = F'{prefix}:{representation}'
         if representation is None:
-            representation = F'h:{self.hex()}'
+            p = sum(1 for c in self if c in range(0x21, 0x7F))
+            if p * 2 >= len(self):
+                from urllib.parse import quote
+                from string import printable
+                representation = F'q:{quote(self,printable)}'
+            else:
+                representation = F'h:{self.hex()}'
         self._representation = representation
         return representation
 
